ValueRange

Struct ValueRange 

pub struct ValueRange { /* private fields */ }
Values per occurrence for an argument

Implementations

Source

impl ValueRange

pub const EMPTY: Self

Nor argument values, or a flag

pub const SINGLE: Self

A single argument value, the most common case for options

pub fn new(range: impl Into<Self>) -> Self

Create a range

Panics

In debug builds, if the range accepts no values. For an exclusive range (start..end) that means end must be greater than start, so both reversed ranges like 10..5 and empty ranges like 5..5 panic.

Examples
let range = ValueRange::new(5);
let range = ValueRange::new(5..10);
let range = ValueRange::new(5..=10);
let range = ValueRange::new(5..);
let range = ValueRange::new(..10);
let range = ValueRange::new(..=10);

While these will panic:

let range = ValueRange::new(10..5);  // Panics! (reversed)
let range = ValueRange::new(5..5);  // Panics! (empty)
pub fn min_values(&self) -> usize

Fewest number of values the argument accepts

pub fn max_values(&self) -> usize

Most number of values the argument accepts

pub fn takes_values(&self) -> bool

Report whether the argument takes any values (ie is a flag)

Examples
let range = ValueRange::new(5);
assert!(range.takes_values());

let range = ValueRange::new(0);
assert!(!range.takes_values());