Enum ColorChoice
enum ColorChoice
Represents the color preferences for program output
Variants
-
Auto Enables colored output only when the output is going to a terminal or TTY.
NOTE: This is the default behavior of
clap.Examples
#-
Always Enables colored output regardless of whether or not the output is going to a terminal/TTY.
Examples
#-
Never Disables colored output no matter if the output is going to a terminal/TTY, or not.
Examples
#
Implementations
impl ColorChoice
fn possible_values() -> impl Iterator<Item = PossibleValue>Report all
possible_values
impl Clone for ColorChoice
fn clone(self: &Self) -> ColorChoice
impl Copy for ColorChoice
impl Debug for ColorChoice
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for ColorChoice
fn default() -> Self
impl Display for ColorChoice
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for ColorChoice
impl Freeze for ColorChoice
impl FromStr for ColorChoice
fn from_str(s: &str) -> Result<Self, <Self as >::Err>
impl PartialEq for ColorChoice
fn eq(self: &Self, other: &ColorChoice) -> bool
impl RefUnwindSafe for ColorChoice
impl Send for ColorChoice
impl StructuralPartialEq for ColorChoice
impl Sync for ColorChoice
impl Unpin for ColorChoice
impl UnsafeUnpin for ColorChoice
impl UnwindSafe for ColorChoice
impl ValueEnum for ColorChoice
fn value_variants<'a>() -> &'a [Self]fn to_possible_value(self: &Self) -> Option<PossibleValue>
impl<T> Any for ColorChoice
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ColorChoice
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ColorChoice
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ColorChoice
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ColorChoice
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ColorChoice
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for ColorChoice
fn to_string(self: &Self) -> String
impl<T, U> Into for ColorChoice
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ColorChoice
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ColorChoice
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>