Struct Id
struct Id(_)
[Arg][crate::Arg] or [ArgGroup][crate::ArgGroup] identifier
This is used for accessing the value in [ArgMatches][crate::ArgMatches] or defining
relationships between Args and ArgGroups with functions like
[Arg::conflicts_with][crate::Arg::conflicts_with].
Implementations
impl Id
fn as_str(self: &Self) -> &strGet the raw string of the
Id
impl AsRef for Id
fn as_ref(self: &Self) -> &str
impl Borrow for Id
fn borrow(self: &Self) -> &str
impl Clone for Id
fn clone(self: &Self) -> Id
impl Debug for Id
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Id
fn default() -> Id
impl Display for Id
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Id
impl Freeze for Id
impl From for Id
fn from(name: &&'static str) -> Self
impl From for Id
fn from(name: &Str) -> Self
impl From for Id
fn from(name: &'static str) -> Self
impl From for Id
fn from(name: Str) -> Self
impl From for Id
fn from(id: &Id) -> Self
impl Hash for Id
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for Id
fn cmp(self: &Self, other: &Id) -> Ordering
impl PartialEq for Id
fn eq(self: &Self, other: &&str) -> bool
impl PartialEq for Id
fn eq(self: &Self, other: &String) -> bool
impl PartialEq for Id
fn eq(self: &Self, other: &str) -> bool
impl PartialEq for Id
fn eq(self: &Self, other: &Str) -> bool
impl PartialEq for Id
fn eq(self: &Self, other: &Id) -> bool
impl PartialOrd for Id
fn partial_cmp(self: &Self, other: &Id) -> Option<Ordering>
impl RefUnwindSafe for Id
impl Send for Id
impl StructuralPartialEq for Id
impl Sync for Id
impl Unpin for Id
impl UnsafeUnpin for Id
impl UnwindSafe for Id
impl<I> IntoResettable for Id
fn into_resettable(self: Self) -> Resettable<Str>
impl<I> IntoResettable for Id
fn into_resettable(self: Self) -> Resettable<String>
impl<T> Any for Id
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Id
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Id
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Id
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Id
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Id
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for Id
fn to_string(self: &Self) -> String
impl<T, U> Into for Id
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Id
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Id
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>