Trait Args
trait Args: FromArgMatches + Sized
Parse a set of arguments into a user-defined container.
Implementing this trait lets a parent container delegate argument parsing behavior to Self.
with:
#[command(flatten)] args: ChildArgs: Attribute can only be used with struct fields that implArgs.Variant(ChildArgs): No attribute is used with enum variants that implArgs.
NOTE: Deriving requires the derive feature flag
Required Methods
fn augment_args(cmd: Command) -> CommandAppend to
Commandso it can instantiateSelfviaFromArgMatches::from_arg_matches_mutThis is used to implement
#[command(flatten)]See also
CommandFactory::command.fn augment_args_for_update(cmd: Command) -> CommandAppend to
Commandso it can instantiateselfviaFromArgMatches::update_from_arg_matches_mutThis is used to implement
#[command(flatten)]See also
CommandFactory::command_for_update.
Provided Methods
fn group_id() -> Option<Id>Report the [
ArgGroup::id][crate::ArgGroup::id] for this set of arguments
Implementors
impl<T: Args> Args for Box<T>