Trait Parser
trait Parser: FromArgMatches + CommandFactory + Sized
Parse command-line arguments into Self.
The primary one-stop-shop trait used to create an instance of a clap
Command, conduct the parsing, and turn the resulting ArgMatches back
into concrete instance of the user struct.
This trait is primarily a convenience on top of FromArgMatches +
CommandFactory which uses those two underlying traits to build the two
fundamental functions parse which uses the std::env::args_os iterator,
and parse_from which allows the consumer to supply the iterator (along
with fallible options for each).
See also Subcommand and Args.
NOTE: Deriving requires the derive feature flag
Provided Methods
fn parse() -> SelfParse from
std::env::args_os(), [exit][Error::exit] on error.fn try_parse() -> Result<Self, Error>Parse from
std::env::args_os(), return Err on error.fn parse_from<I, T>(itr: I) -> Self where I: IntoIterator<Item = T>, T: Into<OsString> + CloneParse from iterator, [exit][Error::exit] on error.
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error> where I: IntoIterator<Item = T>, T: Into<OsString> + CloneParse from iterator, return Err on error.
fn update_from<I, T>(self: &mut Self, itr: I) where I: IntoIterator<Item = T>, T: Into<OsString> + CloneUpdate from iterator, [exit][Error::exit] on error.
Unlike
Parser::parse, this works with an existing instance ofself. The assumption is that all required fields are already provided and anyArgsorSubcommands provided by the user will modify only what is specified.fn try_update_from<I, T>(self: &mut Self, itr: I) -> Result<(), Error> where I: IntoIterator<Item = T>, T: Into<OsString> + CloneUpdate from iterator, return Err on error.
Implementors
impl<T: Parser> Parser for Box<T>